@@ -18,6 +18,7 @@
 """Functions for working with watch files."""
 
 from collections import namedtuple
+from contextlib import suppress
 from dataclasses import dataclass
 import json
 import logging
@@ -30,6 +31,7 @@ from urllib.request import urlopen, Request
 
 from debian.changelog import Changelog
 from debmutate.reformatting import FormattingUnpreservable
+from debmutate.versions import get_snapshot_revision, strip_dfsg_suffix
 from debmutate.watch import (
     Watch,
     WatchEditor,
@@ -65,7 +67,7 @@ COMMON_PGPSIGURL_MANGLES = [
     's/$/.%s/' % ext for ext in ['asc', 'pgp', 'gpg', 'sig', 'sign']]
 
 
-SignatureInfo = namedtuple('SignatureInfo', ['is_valid', 'keys', 'mangles'])
+SignatureInfo = namedtuple('SignatureInfo', ['is_valid', 'keys', 'mangle'])
 
 
 def probe_signature(r, *, pgpsigurlmangle=None, mangles=None,
@@ -115,7 +117,7 @@ def probe_signature(r, *, pgpsigurlmangle=None, mangles=None,
                         home_dir=gpg_context.home_dir):
                     logging.warning(
                         'Unable to retrieve keys: %r',
-                         e.result.signatures)
+                        e.result.signatures)
                     raise KeyRetrievalFailed(
                         [s.fpr for s in e.result.signatures]) from e
                 gr = gpg_context.verify(actual, sig)[1]
@@ -128,7 +130,7 @@ def probe_signature(r, *, pgpsigurlmangle=None, mangles=None,
             if not sig_valid(sig):
                 logging.warning(
                     'Signature from %s in %s for %s not valid',
-                     sig.fpr, pgpsigurl, r.url)
+                    sig.fpr, pgpsigurl, r.url)
                 is_valid = False
             else:
                 needed_keys.add(sig.fpr)
@@ -142,15 +144,13 @@ def candidates_from_setup_py(
         path, good_upstream_versions: Set[str], net_access=False):
     certainty = "likely"
     # Import setuptools in case it replaces distutils
-    try:
+    with suppress(ImportError):
         import setuptools  # noqa: F401
-    except ImportError:
-        pass
     from distutils.core import run_setup
 
     try:
         result = run_setup(os.path.abspath(path), stop_after="config")
-    except BaseException:
+    except BaseException:  # noqa: PIE786
         import traceback
 
         traceback.print_exc()
@@ -262,9 +262,6 @@ def guess_cran_watch_entry(name):
 
 def guess_launchpad_watch_entry(
         parsed_url, good_upstream_versions, net_access=False):
-    from breezy.branch import Branch
-    import re
-
     if not net_access:
         return
     project = parsed_url.path.strip("/").split("/")[0]
@@ -294,7 +291,8 @@ def guess_github_watch_entry(
         return
     branch = Branch.open(urlunparse(parsed_url))
     tags = branch.tags.get_tag_dict()
-    POSSIBLE_PATTERNS = [r"v(\d\S+)", r"(\d\S+)"]
+    POSSIBLE_PATTERNS = [r"v(\d\S+)", r"(\d\S+)",
+                         r".*/[vV]?(\d[^\s+]+)\.tar\.gz"]
     version_pattern = None
     # TODO(jelmer): Maybe use releases API instead?
     # TODO(jelmer): Automatically added mangling for
@@ -320,11 +318,10 @@ def guess_github_watch_entry(
         "project": project,
     }
     matching_pattern = r".*\/%s\.tar\.gz" % version_pattern
-    opts = []
-    opts.append(
+    opts = [
         r"filenamemangle=s/%(pattern)s/%(project)s-$1\.tar\.gz/"
         % {"pattern": matching_pattern, "project": project}
-    )
+    ]
     if uversionmangle:
         opts.append(r"uversionmangle=" + ";".join(uversionmangle))
     # TODO(jelmer): Check for GPG
@@ -377,7 +374,7 @@ def fix_old_github_patterns(updater):
             continue
 
         parts = parsed_url.path.strip('/').split('/')
-        if len(parts) >= 3 and parts[2] in ('tags', 'releases'):
+        if len(parts) >= 3 and parts[2] in ('tags', 'releases'):  # noqa:SIM114
             pass
         elif len(parts) >= 2 and parts[0] == '.*' and parts[1] == 'archive':
             pass
@@ -422,19 +419,43 @@ def watch_entries_certainty(entries, source_package,
                             default_certainty="likely"):
     certainty = "certain"
     for entry in entries:
-        ret = verify_watch_entry(
-            entry, source_package,
-            expected_versions=expected_versions)
-        if ret is False:
+        try:
+            ret = verify_watch_entry(
+                entry, source_package,
+                expected_versions=expected_versions)
+        except WatchEntryVerificationFailure:
             certainty = min_certainty(["possible", certainty])
-        if ret is None:
+        except TemporaryWatchEntryVerficationError:
             certainty = min_certainty([default_certainty, certainty])
+        else:
+            if not ret:
+                certainty = min_certainty(["possible", certainty])
     return certainty
 
 
+class WatchEntryVerificationFailure(Exception):
+    """Failure verifying watch entry."""
+
+
+class TemporaryWatchEntryVerficationError(Exception):
+    """Temporary error verifying watch entry."""
+
+
+class WatchEntryVerificationStatus:
+
+    def __init__(self, entry, releases, missing_versions=None):
+        self.entry = entry
+        self.releases = {r.version: r for r in releases}
+        self.missing_versions = missing_versions
+
+    def __bool__(self):
+        return not self.missing_versions and bool(self.releases)
+
+
 def verify_watch_entry(
         entry: Watch, source_package: str,
-        expected_versions: Optional[List[str]] = None) -> Optional[bool]:
+        expected_versions: Optional[
+            List[str]] = None) -> WatchEntryVerificationStatus:
     try:
         releases = list(sorted(
                 entry.discover(source_package), reverse=True))
@@ -444,35 +465,50 @@ def verify_watch_entry(
             e.geturl(), e)
         if (e.status or 0) // 100 == 5:
             # If the server is unhappy, then the entry could still be valid.
-            return None
+            raise TemporaryWatchEntryVerficationError(str(e)) from e
 
-        return False
+        raise WatchEntryVerificationFailure(str(e)) from e
 
-    if not releases:
-        # No matches is not a good sign
-        return None
+    if expected_versions is None:
+        return WatchEntryVerificationStatus(entry, releases=releases)
 
-    if (expected_versions
-            and all(map(releases.__contains__, expected_versions))):
-        return True
-
-    return True
+    found_versions = set([str(r.version) for r in releases])
+    missing_versions = set(expected_versions) - found_versions
+    return WatchEntryVerificationStatus(
+        entry, releases=releases, missing_versions=missing_versions)
 
 
-def report_fatal(code: str, description: str) -> None:
+def report_fatal(code: str, description: str, context=None) -> None:
     if os.environ.get('SVP_API') == '1':
         with open(os.environ['SVP_RESULT'], 'w') as f:
             json.dump({
                 'result_code': code,
-                'description': description}, f)
+                'description': description,
+                'context': context}, f)
     logging.fatal('%s', description)
 
 
 def verify_watch_file(watch_file, source_package, expected_versions):
-    for entry in watch_file.entries:
-        if not verify_watch_entry(entry, source_package, expected_versions):
-            return False
-    return True
+    ret = []
+    for entry in getattr(watch_file, 'entries', []):
+        ret.append(verify_watch_entry(
+            entry, source_package, expected_versions))
+    return ret
+
+
+def svp_context(status):
+    return {
+        'entries': {
+            'text': str(entry_status.entry),
+            'releases': {
+                str(r.version): {
+                    'url': r.url,
+                } for r in entry_status.releases.values()
+            },
+            'missing_versions':
+                [str(x) for x in entry_status.missing_versions]
+        } for entry_status in (status or [])
+    }
 
 
 def main():  # noqa: C901
@@ -581,30 +617,55 @@ def main():  # noqa: C901
             allow_reformatting = False
 
         good_upstream_versions = set()
-        expected_versions = list(sorted(good_upstream_versions))[-5:]
 
         with open('debian/changelog', 'r') as f:
             cl = Changelog(f)
             for entry in cl:
-                good_upstream_versions.add(entry.version.upstream_version)
+                uv = strip_dfsg_suffix(entry.version.upstream_version)
+                if get_snapshot_revision(uv) is not None:
+                    continue
+                good_upstream_versions.add(uv)
             package = cl.package
 
+        expected_versions = list(sorted(good_upstream_versions))[-5:]
+
+        status = None
         try:
-            with WatchEditor(allow_reformatting=allow_reformatting) as updater:
-                if verify_watch_file(updater.watch_file, package,
-                                     expected_versions):
+            with WatchEditor(allow_reformatting=allow_reformatting,
+                             allow_missing=False) as updater:
+                try:
+                    status = verify_watch_file(
+                        updater.watch_file, package, expected_versions)
+                except (TemporaryWatchEntryVerficationError,
+                        WatchEntryVerificationFailure):
+                    status = [None]
+                if status and all(status):
                     report_fatal(
                         'nothing-to-do',
-                        'Existing watch file has valid entries')
+                        'Existing watch file has valid entries',
+                        context=svp_context(status))
                     return 0
                 fix_watch_issues(updater)
-                if not verify_watch_file(updater.watch_file, package,
-                                         expected_versions):
+                try:
+                    status = verify_watch_file(
+                        updater.watch_file, package, expected_versions)
+                except WatchEntryVerificationFailure:
+                    status = [None]
+                except TemporaryWatchEntryVerficationError as e:
+                    report_fatal('temporary-verification-error', str(e))
+                    return 1
+                if status or not all(status):
                     candidates = find_candidates(
                         '.', good_upstream_versions,
                         net_access=not args.disable_net_access)
+                    if len(candidates) == 0:
+                        report_fatal(
+                            'no-download-urls-found',
+                            'No candidates for the watch file were found')
+                        return 1
                     updater.allow_reformatting = True
                     updater.watch_file.entries = [candidates[0].watch]
+                    status = None
         except FileNotFoundError:
             candidates = find_candidates(
                 '.', good_upstream_versions,
@@ -619,27 +680,42 @@ def main():  # noqa: C901
 
             with open('debian/watch', 'w') as f:
                 wf.dump(f)
+            status = None
         except FormattingUnpreservable as e:
             report_fatal('formatting-unpreservable',
                          "Unable to preserve formatting of %s" % e.path)
             return 1
 
-    if args.verify:
+    if args.verify and status is None:
         with WatchEditor() as updater:
-            if not verify_watch_file(updater.watch_file, package,
-                                     expected_versions):
+            try:
+                status = verify_watch_file(
+                    updater.watch_file, package, expected_versions)
+            except WatchEntryVerificationFailure as e:
                 report_fatal(
                     'verification-failed',
                     'Unable to verify watch entry: %s'
-                    % updater.watch_file.entries[0])
+                    % e)
+                return 1
+            except TemporaryWatchEntryVerficationError as e:
+                report_fatal(
+                    'temporary-verification-error',
+                    'Unable to verify watch entry: %s'
+                    % e)
+                return 1
+            if not status or not all(status):
+                report_fatal(
+                    'verification-failed',
+                    'Unable to watch entries; missing versions: %r'
+                    % status[0].missing_versions,
+                    context=svp_context(status))
                 return 1
 
     if os.environ.get("SVP_API") == "1":
         with open(os.environ["SVP_RESULT"], "w") as f:
             json.dump({
                 "description": "Update watch file.",
-                "context": {
-                }
+                "context": svp_context(status),
             }, f)
 
     return 0
